@@ -602,7 +602,7 @@ sub _GetParams {
         next if !$Self->{ParamObject}->GetParam( Param => 'KeyIndex' . $KeyCounter );
         $KeyIndex++;
         for my $KeyItem (qw(KeyMapTypeStrg KeyName KeyMapNew ValueCounter)) {
-            my $KeyAux = $Self->{ParamObject}->GetParam( Param => $KeyItem . $KeyCounter ) || '';
+            my $KeyAux = $Self->{ParamObject}->GetParam( Param => $KeyItem . $KeyCounter ) // '';
             $GetParam->{ $KeyItem . $KeyIndex } = $KeyAux;
             if ( $KeyItem eq 'ValueCounter' && $KeyAux eq '' ) {
                 $GetParam->{ $KeyItem . $KeyIndex } = 0;
