@@ -69,9 +69,11 @@ sub Run {
 
         my $Note = '';
         my ( %GetParam, %Errors );
-        for my $Parameter (qw(ID Name Text Comment ValidID)) {
-            $GetParam{$Parameter} = $Self->{ParamObject}->GetParam( Param => $Parameter ) || '';
+        for my $Parameter (qw(ID Name Comment ValidID)) {
+            $GetParam{$Parameter}
+                = $Self->{ParamObject}->GetParam( Param => $Parameter ) || '';
         }
+        $GetParam{'Text'} = $Self->{ParamObject}->GetParam( Param => 'Text', Raw => 1 ) || '';
 
         # get content type
         my $ContentType = 'text/plain';
@@ -156,9 +158,11 @@ sub Run {
 
         my $Note = '';
         my ( %GetParam, %Errors );
-        for my $Parameter (qw(ID Name Text Comment ValidID)) {
-            $GetParam{$Parameter} = $Self->{ParamObject}->GetParam( Param => $Parameter ) || '';
+        for my $Parameter (qw(ID Name Comment ValidID)) {
+            $GetParam{$Parameter}
+                = $Self->{ParamObject}->GetParam( Param => $Parameter ) || '';
         }
+        $GetParam{'Text'} = $Self->{ParamObject}->GetParam( Param => 'Text', Raw => 1 ) || '';
 
         # get content type
         my $ContentType = 'text/plain';
