@@ -343,17 +343,6 @@ sub Run {
             $Self->{Profile} = 'last-search';
         }
 
-        # store last queue screen
-        my $URL
-            = "Action=AgentTicketSearch;Subaction=Search;Profile=$Self->{Profile};SortBy=$Self->{SortBy}"
-            . ";OrderBy=$Self->{OrderBy};TakeLastSearch=1;StartHit=$Self->{StartHit}";
-
-        $Self->{SessionObject}->UpdateSessionID(
-            SessionID => $Self->{SessionID},
-            Key       => 'LastScreenOverview',
-            Value     => $URL,
-        );
-
         # save search profile (under last-search or real profile name)
         $Self->{SaveProfile} = 1;
 
@@ -622,6 +611,22 @@ sub Run {
                     DynamicFields => 1,
                 );
 
+                if ( !%Data ) {
+
+                    # get ticket data instead
+                    %Data = $Self->{TicketObjectSearch}->TicketGet(
+                        TicketID      => $TicketID,
+                        DynamicFields => 1,
+                    );
+
+                    # set missing information
+                    $Data{Subject} = $Data{Title} || 'Untitled';
+                    $Data{Body} = $Self->{LayoutObject}->{LanguageObject}->Get(
+                        'This item has no articles yet.'
+                    );
+                    $Data{From} = '--';
+                }
+
                 for my $Key (qw(State Lock)) {
                     $Data{$Key} = $Self->{LayoutObject}->{LanguageObject}->Get( $Data{$Key} );
                 }
@@ -634,13 +639,21 @@ sub Run {
                         TicketID      => $TicketID,
                         DynamicFields => 0,
                     );
-                    for my $Articles (@Article) {
-                        if ( $Articles->{Body} ) {
-                            $Data{ArticleTree}
-                                .= "\n-->||$Articles->{ArticleType}||$Articles->{From}||"
-                                . $Articles->{Created}
-                                . "||<--------------\n"
-                                . $Articles->{Body};
+
+                    if ( $#Article == -1 ) {
+                        $Data{ArticleTree}
+                            .= 'This item has no articles yet.';
+                    }
+                    else
+                    {
+                        for my $Articles (@Article) {
+                            if ( $Articles->{Body} ) {
+                                $Data{ArticleTree}
+                                    .= "\n-->||$Articles->{ArticleType}||$Articles->{From}||"
+                                    . $Articles->{Created}
+                                    . "||<--------------\n"
+                                    . $Articles->{Body};
+                            }
                         }
                     }
                 }
@@ -715,7 +728,7 @@ sub Run {
 
             my %HeaderMap = (
                 TicketNumber => 'Ticket Number',
-                CustomerName => 'customer realname',
+                CustomerName => 'Customer Realname',
             );
 
             my @CSVHeadTranslated
@@ -766,8 +779,8 @@ sub Run {
                     );
 
                     # set missing information
-                    $Data{Subject} = $Data{Title};
-                    $Data{From}    = '--';
+                    $Data{Subject} = $Data{Title} || 'Untitled';
+                    $Data{From} = '--';
                 }
 
                 # customer info
@@ -1008,6 +1021,17 @@ sub Run {
                 );
             }
 
+            # store last overview screen
+            my $URL
+                = "Action=AgentTicketSearch;Subaction=Search;Profile=$Self->{Profile};SortBy=$Self->{SortBy}"
+                . ";OrderBy=$Self->{OrderBy};TakeLastSearch=1;StartHit=$Self->{StartHit}";
+
+            $Self->{SessionObject}->UpdateSessionID(
+                SessionID => $Self->{SessionID},
+                Key       => 'LastScreenOverview',
+                Value     => $URL,
+            );
+
             # start html page
             my $Output = $Self->{LayoutObject}->Header();
             $Output .= $Self->{LayoutObject}->NavigationBar();
@@ -1132,46 +1156,28 @@ sub Run {
         }
         my @Attributes = (
             {
-                Key   => 'TicketNumber',
-                Value => 'Ticket Number',
+                Key   => 'StateIDs',
+                Value => 'State',
             },
             {
-                Key   => 'Fulltext',
-                Value => 'Fulltext',
+                Key   => 'QueueIDs',
+                Value => 'Queue',
             },
             {
-                Key   => 'Title',
-                Value => 'Title',
+                Key   => 'ArticleCreateTimePoint',
+                Value => 'Article Create Time (before/after)',
             },
             {
-                Key      => '',
-                Value    => '-',
-                Disabled => 1,
-            },
-            {
-                Key   => 'From',
-                Value => 'From',
-            },
-            {
-                Key   => 'To',
-                Value => 'To',
-            },
-            {
-                Key   => 'Cc',
-                Value => 'Cc',
-            },
-            {
-                Key   => 'Subject',
-                Value => 'Subject',
+                Key   => 'ArticleCreateTimeSlot',
+                Value => 'Article Create Time (between)',
             },
             {
                 Key   => 'Body',
                 Value => 'Body',
             },
             {
-                Key      => '',
-                Value    => '-',
-                Disabled => 1,
+                Key   => 'Cc',
+                Value => 'Cc',
             },
             {
                 Key   => 'CustomerID',
@@ -1182,12 +1188,82 @@ sub Run {
                 Value => 'Customer User Login',
             },
             {
-                Key   => 'StateIDs',
-                Value => 'State',
+                Key   => 'From',
+                Value => 'From',
             },
             {
-                Key   => 'QueueIDs',
-                Value => 'Queue',
+                Key   => 'Fulltext',
+                Value => 'Fulltext',
+            },
+        );
+
+        if ( $Self->{ConfigObject}->Get('Ticket::ArchiveSystem') ) {
+            push @Attributes, (
+                {
+                    Key   => 'SearchInArchive',
+                    Value => 'Archive Search',
+                },
+            );
+        }
+
+        push @Attributes, (
+            {
+                Key   => 'Subject',
+                Value => 'Subject',
+            },
+            {
+                Key      => '',
+                Value    => '-',
+                Disabled => 1,
+            },
+            {
+                Key   => 'TicketChangeTimePoint',
+                Value => 'Ticket Change Time (before/after)',
+            },
+            {
+                Key   => 'TicketChangeTimeSlot',
+                Value => 'Ticket Change Time (between)',
+            },
+            {
+                Key   => 'TicketCloseTimePoint',
+                Value => 'Ticket Close Time (before/after)',
+            },
+            {
+                Key   => 'TicketCloseTimeSlot',
+                Value => 'Ticket Close Time (between)',
+            },
+            {
+                Key   => 'TicketCreateTimePoint',
+                Value => 'Ticket Create Time (before/after)',
+            },
+            {
+                Key   => 'TicketCreateTimeSlot',
+                Value => 'Ticket Create Time (between)',
+            },
+            {
+                Key   => 'TicketEscalationTimePoint',
+                Value => 'Ticket Escalation Time (before/after)',
+            },
+            {
+                Key   => 'TicketEscalationTimeSlot',
+                Value => 'Ticket Escalation Time (between)',
+            },
+            {
+                Key   => 'TicketNumber',
+                Value => 'Ticket Number',
+            },
+            {
+                Key   => 'Title',
+                Value => 'Title',
+            },
+            {
+                Key   => 'To',
+                Value => 'To',
+            },
+            {
+                Key      => '',
+                Value    => '-',
+                Disabled => 1,
             },
             {
                 Key   => 'PriorityIDs',
@@ -1206,6 +1282,7 @@ sub Run {
                 Value => 'Created by',
             },
         );
+
         if ( $Self->{ConfigObject}->Get('Ticket::Watcher') ) {
             push @Attributes, (
                 {
@@ -1230,6 +1307,14 @@ sub Run {
                 },
             );
         }
+
+        push @Attributes, (
+            {
+                Key   => 'LockIDs',
+                Value => 'Lock',
+            },
+        );
+
         if ( $Self->{ConfigObject}->Get('Ticket::Service') ) {
             push @Attributes, (
                 {
@@ -1399,60 +1484,6 @@ sub Run {
             }
         }
 
-        push @Attributes, (
-            {
-                Key   => 'LockIDs',
-                Value => 'Lock',
-            },
-            {
-                Key   => 'TicketCreateTimePoint',
-                Value => 'Ticket Create Time (before/after)',
-            },
-            {
-                Key   => 'TicketCreateTimeSlot',
-                Value => 'Ticket Create Time (between)',
-            },
-            {
-                Key   => 'TicketChangeTimePoint',
-                Value => 'Ticket Change Time (before/after)',
-            },
-            {
-                Key   => 'TicketChangeTimeSlot',
-                Value => 'Ticket Change Time (between)',
-            },
-            {
-                Key   => 'TicketCloseTimePoint',
-                Value => 'Ticket Close Time (before/after)',
-            },
-            {
-                Key   => 'TicketCloseTimeSlot',
-                Value => 'Ticket Close Time (between)',
-            },
-            {
-                Key   => 'TicketEscalationTimePoint',
-                Value => 'Ticket Escalation Time (before/after)',
-            },
-            {
-                Key   => 'TicketEscalationTimeSlot',
-                Value => 'Ticket Escalation Time (between)',
-            },
-            {
-                Key   => 'ArticleCreateTimePoint',
-                Value => 'Article Create Time (before/after)',
-            },
-            {
-                Key   => 'ArticleCreateTimeSlot',
-                Value => 'Article Create Time (between)',
-            },
-        );
-        if ( $Self->{ConfigObject}->Get('Ticket::ArchiveSystem') ) {
-            push @Attributes, (
-                {
-                    Key   => 'SearchInArchive',
-                    Value => 'Archive Search',
-                },
-            );
-        }
         $Param{AttributesStrg} = $Self->{LayoutObject}->BuildSelection(
             Data     => \@Attributes,
             Name     => 'Attribute',
