@@ -279,7 +279,6 @@ sub Run {
             TemplateTypes => 1,
             Valid         => 1,
         );
-
         $Self->_ArticleItem(
             Ticket            => \%Ticket,
             Article           => \%Article,
@@ -874,46 +873,6 @@ sub MaskAgentZoom {
         );
     }
 
-    # test access to frontend module for Customer
-    my $Access = $Self->{LayoutObject}->Permission(
-        Action => 'AgentTicketCustomer',
-        Type   => 'rw',
-    );
-
-    # acl check
-    if (
-        $Access
-        && defined $AclAction{AgentTicketCustomer}
-        && !$AclAction{AgentTicketCustomer}
-        )
-    {
-        $Access = 0;
-    }
-
-    if ($Access) {
-
-        # test access to ticket
-        my $Config = $Self->{ConfigObject}->Get('Ticket::Frontend::AgentTicketCustomer');
-        if ( $Config->{Permission} ) {
-            my $OK = $Self->{TicketObject}->Permission(
-                Type     => $Config->{Permission},
-                TicketID => $Ticket{TicketID},
-                UserID   => $Self->{UserID},
-                LogNo    => 1,
-            );
-            if ( !$OK ) {
-                $Access = 0;
-            }
-        }
-    }
-
-    # define proper DTL block based on permissions
-    my $CustomerIDBlock = $Access ? 'CustomerIDRW' : 'CustomerIDRO';
-    $Self->{LayoutObject}->Block(
-        Name => $CustomerIDBlock,
-        Data => \%Ticket,
-    );
-
     # show total accounted time if feature is active:
     if ( $Self->{ConfigObject}->Get('Ticket::Frontend::AccountTime') ) {
         $Ticket{TicketTimeUnits} = $Self->{TicketObject}->TicketAccountedTimeGet(%Ticket);
@@ -1938,14 +1897,35 @@ sub _ArticleItem {
             if ($Access) {
 
                 # get StandardResponsesStrg
-                $Param{StandardResponses}->{0}
-                    = '- ' . $Self->{LayoutObject}->{LanguageObject}->Get('Reply') . ' -';
+                my %StandardResponseHash = %{ $Param{StandardResponses} || {} };
+
+              # get revers StandardResponseHash because we need to sort by Values
+              # from %ReverseStandardResponseHash we get value of Key by %StandardResponseHash Value
+              # and @StandardResponseArray is created as array of hashes with elements Key and Value
+
+                my %ReverseStandardResponseHash = reverse %StandardResponseHash;
+                my @StandardResponseArray       = map {
+                    {
+                        Key   => $ReverseStandardResponseHash{$_},
+                        Value => $_
+                    }
+                } sort values %StandardResponseHash;
+
+                unshift(
+                    @StandardResponseArray,
+                    {
+                        Key   => '0',
+                        Value => '- '
+                            . $Self->{LayoutObject}->{LanguageObject}->Get('Reply') . ' -',
+                        Selected => 1,
+                    }
+                );
 
                 # build html string
                 my $StandardResponsesStrg = $Self->{LayoutObject}->BuildSelection(
                     Name => 'ResponseID',
                     ID   => 'ResponseID',
-                    Data => $Param{StandardResponses},
+                    Data => \@StandardResponseArray,
                 );
 
                 $Self->{LayoutObject}->Block(
@@ -1997,13 +1977,21 @@ sub _ArticleItem {
                     }
                 }
                 if ( $RecipientCount > 1 ) {
-                    $Param{StandardResponses}->{0}
-                        = '- ' . $Self->{LayoutObject}->{LanguageObject}->Get('Reply All') . ' -';
+                    shift(@StandardResponseArray);
+                    unshift(
+                        @StandardResponseArray,
+                        {
+                            Key   => '0',
+                            Value => '- '
+                                . $Self->{LayoutObject}->{LanguageObject}->Get('Reply All') . ' -',
+                            Selected => 1,
+                        }
+                    );
 
                     $StandardResponsesStrg = $Self->{LayoutObject}->BuildSelection(
                         Name => 'ResponseID',
                         ID   => 'ResponseIDAll',
-                        Data => $Param{StandardResponses},
+                        Data => \@StandardResponseArray,
                     );
 
                     $Self->{LayoutObject}->Block(
@@ -2066,15 +2054,35 @@ sub _ArticleItem {
             if ($Access) {
                 if ( IsHashRefWithData( $Param{StandardForwards} ) ) {
 
-                    # get StandarForwardsStrg
-                    $Param{StandardForwards}->{0}
-                        = '- ' . $Self->{LayoutObject}->{LanguageObject}->Get('Forward') . ' -';
+                    # get StandardForwardsStrg
+                    my %StandardForwardHash = %{ $Param{StandardForwards} };
+
+               # get revers @StandardForwardHash because we need to sort by Values
+               # from %ReverseStandarForward we get value of Key by %StandardForwardHash Value
+               # and @StandardForwardArray is created as array of hashes with elements Key and Value
+                    my %ReverseStandarForward = reverse %StandardForwardHash;
+                    my @StandardForwardArray  = map {
+                        {
+                            Key   => $ReverseStandarForward{$_},
+                            Value => $_
+                        }
+                    } sort values %StandardForwardHash;
+
+                    unshift(
+                        @StandardForwardArray,
+                        {
+                            Key   => '0',
+                            Value => '- '
+                                . $Self->{LayoutObject}->{LanguageObject}->Get('Forward') . ' -',
+                            Selected => 1,
+                        }
+                    );
 
                     # build html string
                     my $StandarForwardsStrg = $Self->{LayoutObject}->BuildSelection(
                         Name => 'ForwardTemplateID',
                         ID   => 'ForwardTemplateID',
-                        Data => $Param{StandardForwards},
+                        Data => \@StandardForwardArray,
                     );
 
                     $Self->{LayoutObject}->Block(
