@@ -568,6 +568,7 @@ sub Run {
                     $Data{Body} = $Self->{LayoutObject}->{LanguageObject}->Get(
                         'This item has no articles yet.'
                     );
+                    $Data{From} = '--';
                 }
 
                 for my $Key (qw(State Lock)) {
@@ -591,6 +592,23 @@ sub Run {
                                 . $Articles->{Body};
                         }
                     }
+
+                    if ( $#Article == -1 ) {
+                        $Data{ArticleTree}
+                            .= 'This item has no articles yet.';
+                    }
+                    else
+                    {
+                        for my $Articles (@Article) {
+                            if ( $Articles->{Body} ) {
+                                $Data{ArticleTree}
+                                    .= "\n-->||$Articles->{ArticleType}||$Articles->{From}||"
+                                    . $Articles->{Created}
+                                    . "||<--------------\n"
+                                    . $Articles->{Body};
+                            }
+                        }
+                    }
                 }
 
                 # customer info (customer name)
@@ -662,7 +680,7 @@ sub Run {
 
             my %HeaderMap = (
                 TicketNumber => 'Ticket Number',
-                CustomerName => 'customer realname',
+                CustomerName => 'Customer Realname',
             );
 
             my @CSVHeadTranslated
@@ -712,6 +730,7 @@ sub Run {
                     $Article{Body} = $Self->{LayoutObject}->{LanguageObject}->Get(
                         'This item has no articles yet.'
                     );
+                    $Article{From} = '--';
                 }
 
                 # customer info
