@@ -171,7 +171,7 @@ sub Run {
 
     # get params
     my %GetParam;
-    for my $Key (qw( Subject Body StateID PriorityID)) {
+    for my $Key (qw(Subject Body StateID PriorityID)) {
         $GetParam{$Key} = $Self->{ParamObject}->GetParam( Param => $Key );
     }
 
@@ -223,11 +223,13 @@ sub Run {
             %GetParam,
             %ACLCompatGetParam,
             CustomerUserID => $CustomerUser || '',
+            TicketID => $Self->{TicketID},
         );
         my $NextStates = $Self->_GetNextStates(
             %GetParam,
             %ACLCompatGetParam,
             CustomerUserID => $CustomerUser || '',
+            TicketID => $Self->{TicketID},
         );
 
         # update Dynamic Fields Possible Values via AJAX
@@ -522,6 +524,7 @@ sub Run {
                 TicketState   => $Ticket{State},
                 TicketStateID => $Ticket{StateID},
                 %GetParam,
+                %ACLCompatGetParam,
                 DynamicFieldHTML => \%DynamicFieldHTML,
             );
             $Output .= $Self->{LayoutObject}->CustomerFooter();
@@ -794,6 +797,7 @@ sub Run {
         TicketState   => $Ticket{State},
         TicketStateID => $Ticket{StateID},
         %GetParam,
+        %ACLCompatGetParam,
         DynamicFieldHTML => \%DynamicFieldHTML,
     );
 
@@ -818,6 +822,9 @@ sub _GetNextStates {
             %Param,
             Action         => $Self->{Action},
             CustomerUserID => $Self->{UserID},
+
+            # %Param could contain Ticket Type as only Type, it should not be sent
+            Type => undef,
         );
     }
     return \%NextStates;
@@ -900,6 +907,9 @@ sub _Mask {
         }
     }
 
+    # set display options
+    $Param{Hook} = $Self->{ConfigObject}->Get('Ticket::Hook') || 'Ticket#';
+
     # ticket priority flag
     if ( $Self->{Config}->{AttributesView}->{Priority} ) {
         $Self->{LayoutObject}->Block(
@@ -997,8 +1007,6 @@ sub _Mask {
         'TicketID' => $Self->{TicketID}
     );
 
-    #    my $ProcessData;
-    #    my $ActivityData;
     # show process widget  and activity dialogs on process tickets
     if ($IsProcessTicket) {
 
@@ -1541,7 +1549,7 @@ sub _Mask {
 
         # check subject
         if ( !$Param{Subject} ) {
-            $Param{Subject} = "Re: $Param{Title}";
+            $Param{Subject} = "Re: " . ( $Param{Title} // '' );
         }
         $Self->{LayoutObject}->Block(
             Name => 'FollowUp',
@@ -1563,10 +1571,9 @@ sub _Mask {
 
         # build next states string
         if ( $Self->{Config}->{State} ) {
-            my %NextStates = $Self->{TicketObject}->TicketStateList(
-                TicketID       => $Self->{TicketID},
-                Action         => $Self->{Action},
-                CustomerUserID => $Self->{UserID},
+            my $NextStates = $Self->_GetNextStates(
+                %Param,
+                TicketID => $Self->{TicketID},
             );
             my %StateSelected;
             if ( $Param{StateID} ) {
@@ -1576,7 +1583,7 @@ sub _Mask {
                 $StateSelected{SelectedValue} = $Self->{Config}->{StateDefault};
             }
             $Param{NextStatesStrg} = $Self->{LayoutObject}->BuildSelection(
-                Data => \%NextStates,
+                Data => $NextStates,
                 Name => 'StateID',
                 %StateSelected,
             );
@@ -1588,9 +1595,9 @@ sub _Mask {
 
         # get priority
         if ( $Self->{Config}->{Priority} ) {
-            my %Priorities = $Self->{TicketObject}->TicketPriorityList(
-                CustomerUserID => $Self->{UserID},
-                Action         => $Self->{Action},
+            my $Priorities = $Self->_GetPriorities(
+                %Param,
+                TicketID => $Self->{TicketID},
             );
             my %PrioritySelected;
             if ( $Param{PriorityID} ) {
@@ -1601,7 +1608,7 @@ sub _Mask {
                     || '3 normal';
             }
             $Param{PriorityStrg} = $Self->{LayoutObject}->BuildSelection(
-                Data => \%Priorities,
+                Data => $Priorities,
                 Name => 'PriorityID',
                 %PrioritySelected,
             );
