@@ -122,11 +122,11 @@ sub Check {
 
                         # remember decrypted attachement, to add it later
                         push @Attachments, {
-                            Content     => $AttachmentContent,
-                            ContentType => $Attachment{ContentType},
-                            Filename    => $AttachmentFilename,
-                            ArticleID   => $Self->{ArticleID},
-                            UserID      => $Self->{UserID},
+                            %Attachment,
+                            Content   => $AttachmentContent,
+                            Filename  => $AttachmentFilename,
+                            ArticleID => $Self->{ArticleID},
+                            UserID    => $Self->{UserID},
                         };
                     }
 
@@ -296,11 +296,9 @@ sub Check {
                     # write attachments to the storage
                     for my $Attachment ( $ParserObject->GetAttachments() ) {
                         $Self->{TicketObject}->ArticleWriteAttachment(
-                            Content     => $Attachment->{Content},
-                            Filename    => $Attachment->{Filename},
-                            ContentType => $Attachment->{ContentType},
-                            ArticleID   => $Self->{ArticleID},
-                            UserID      => $Self->{UserID},
+                            %{$Attachment},
+                            ArticleID => $Self->{ArticleID},
+                            UserID    => $Self->{UserID},
                         );
                     }
                 }
