@@ -244,7 +244,17 @@ sub TableCreate {
             if ( $Self->{ConfigObject}->Get('Database::ShellOutput') ) {
                 $Shell = "/\n--";
             }
-            push( @Return2, "DROP SEQUENCE $Sequence" );
+
+            push(
+                @Return2,
+                "BEGIN\n"
+                    . "  EXECUTE IMMEDIATE 'DROP SEQUENCE $Sequence';\n"
+                    . "EXCEPTION\n"
+                    . "  WHEN OTHERS THEN NULL;\n"
+                    . "END;\n"
+                    . "$Shell",
+            );
+
             push(
                 @Return2,
                 "CREATE SEQUENCE $Sequence\n"
@@ -255,19 +265,20 @@ sub TableCreate {
                     . "CACHE 20\n"
                     . "ORDER",
             );
+
             push(
                 @Return2,
                 "CREATE OR REPLACE TRIGGER $Sequence"
                     . "_t\n"
-                    . "before insert on $TableName\n"
-                    . "for each row\n"
-                    . "begin\n"
-                    . "  if :new.$Tag->{Name} IS NULL then\n"
-                    . "    select $Sequence.nextval\n"
-                    . "    into :new.$Tag->{Name}\n"
-                    . "    from dual;\n"
-                    . "  end if;\n"
-                    . "end;\n"
+                    . "BEFORE INSERT ON $TableName\n"
+                    . "FOR EACH ROW\n"
+                    . "BEGIN\n"
+                    . "  IF :new.$Tag->{Name} IS NULL THEN\n"
+                    . "    SELECT $Sequence.nextval\n"
+                    . "    INTO :new.$Tag->{Name}\n"
+                    . "    FROM DUAL;\n"
+                    . "  END IF;\n"
+                    . "END;\n"
                     . "$Shell",
             );
         }
@@ -352,7 +363,9 @@ sub TableDrop {
                     . "----------------------------------------------------------\n";
             }
         }
+
         $SQL .= "DROP TABLE $Tag->{Name} CASCADE CONSTRAINTS";
+
         return ($SQL);
     }
     return ();
@@ -580,14 +593,9 @@ sub IndexCreate {
             $SQL .= ', ';
         }
         $SQL .= $Array[$_]->{Name};
-        if ( $Array[$_]->{Size} ) {
-
-            #           $SQL .= "($Array[$_]->{Size})";
-        }
     }
     $SQL .= ')';
 
-    # return SQL
     return ($SQL);
 
 }
@@ -707,7 +715,6 @@ sub UniqueCreate {
     }
     $SQL .= ')';
 
-    # return SQL
     return ($SQL);
 
 }
@@ -743,6 +750,7 @@ sub Insert {
     my $SQL    = '';
     my @Keys   = ();
     my @Values = ();
+    TAG:
     for my $Tag (@Param) {
         if ( $Tag->{Tag} eq 'Insert' && $Tag->{TagType} eq 'Start' ) {
             if ( $Self->{ConfigObject}->Get('Database::ShellOutput') ) {
@@ -757,9 +765,8 @@ sub Insert {
         if ( $Tag->{Tag} eq 'Data' && $Tag->{TagType} eq 'Start' ) {
 
             # do not use auto increment values
-            if ( $Tag->{Type} && $Tag->{Type} =~ /^AutoIncrement$/i ) {
-                next;
-            }
+            next TAG if $Tag->{Type} && $Tag->{Type} =~ m{ ^AutoIncrement$ }xmsi;
+
             $Tag->{Key} = ${ $Self->Quote( \$Tag->{Key} ) };
             push @Keys, $Tag->{Key};
             my $Value;
