@@ -98,6 +98,9 @@ if ( $DatabaseDSN =~ m/:mysql/i ) {
 elsif ( $DatabaseDSN =~ m/:pg/i ) {
     $DB     = 'PostgreSQL';
     $DBDump = 'psql';
+    if ( $DatabaseDSN !~ m/host=/i ) {
+        $DatabaseHost = ''
+    }
 }
 else {
     print STDERR "ERROR: Can't backup, no database dump support!\n";
@@ -199,6 +202,10 @@ if ( $DB =~ m/mysql/i ) {
     }
 }
 else {
+    if ($DatabaseHost) {
+        $DatabaseHost = "-h $DatabaseHost"
+    }
+
     if ( -e "$Opts{b}/DatabaseBackup.sql.gz" ) {
         print "decompresses SQL-file ...\n";
         system("gunzip $Opts{b}/DatabaseBackup.sql.gz");
@@ -209,7 +216,7 @@ else {
         }
         print "cat SQL-file into $DB database\n";
         system(
-            "cat $Opts{b}/DatabaseBackup.sql | psql -U$DatabaseUser -h$DatabaseHost $Database"
+            "cat $Opts{b}/DatabaseBackup.sql | psql -U$DatabaseUser $DatabaseHost $Database"
         );
         print "compress SQL-file...\n";
         system("gzip $Opts{b}/DatabaseBackup.sql");
@@ -224,7 +231,7 @@ else {
         }
         print "cat SQL-file into $DB database\n";
         system(
-            "cat $Opts{b}/DatabaseBackup.sql | psql -U$DatabaseUser -h$DatabaseHost $Database"
+            "cat $Opts{b}/DatabaseBackup.sql | psql -U$DatabaseUser $DatabaseHost $Database"
         );
         print "compress SQL-file...\n";
         system("bzip2 $Opts{b}/DatabaseBackup.sql");
