@@ -37,7 +37,7 @@ Core.Agent.CustomerSearch = (function (TargetNS) {
         var Data = {
             Action: 'AgentCustomerSearch',
             Subaction: 'CustomerInfo',
-            CustomerUserID: CustomerUserID || 1
+            CustomerUserID: CustomerUserID
         };
         Core.AJAX.FunctionCall(Core.Config.Get('Baselink'), Data, function (Response) {
             // set CustomerID
@@ -426,6 +426,16 @@ Core.Agent.CustomerSearch = (function (TargetNS) {
         if ((Core.Config.Get('Action') === 'AgentTicketEmail' || Core.Config.Get('Action') === 'AgentTicketCompose' || Core.Config.Get('Action') === 'AgentTicketForward') && $('#CryptKeyID').length) {
             Core.AJAX.FormUpdate( $('#' + Field).closest('form'), 'AJAXUpdate', '', ['CryptKeyID']);
         }
+
+        // now that we know that at least one customer has been added,
+        // we can remove eventual errors from the customer field
+        $('#FromCustomer, #ToCustomer')
+            .removeClass('Error ServerError')
+            .closest('.Field')
+            .prev('label')
+            .removeClass('LabelError');
+        Core.Form.ErrorTooltips.HideTooltip();
+
         return false;
     };
 
